@@ -119,8 +119,6 @@ const char *        get_last_field               (const char *line,
 
 char *              get_temp_work_dir            (void);
 
-char *              get_temp_work_dir_name       (void);
-
 char *              str_substitute               (const char *str,
 						  const char *from_str,
 						  const char *to_str);
@@ -141,4 +139,7 @@ char*               file_list__get_prev_field    (const char *line,
 						  int         start_from,
 						  int         field_n);
 
+gboolean            check_permissions            (const char *path,
+						  int         mode);
+
 #endif /* FILE_UTILS_H */
